storetesting

package
v0.0.0-...-40a50d0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 12, 2015 License: AGPL-3.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var Charms = testing.NewRepo("charm-repo", "quantal")

Functions

func MongoJSEnabled

func MongoJSEnabled() bool

MongoJSEnabled reports whether testing code should run tests that rely on JavaScript inside MongoDB.

Types

type ElasticSearchSuite

type ElasticSearchSuite struct {
	ES *elasticsearch.Database

	TestIndex string
	// contains filtered or unexported fields
}

ElasticSearchSuite defines a test suite that connects to an elastic-search server. The address of the server depends on the value of the JUJU_TEST_ELASTICSEARCH environment variable, which can be "none" (do not start or connect to a server) or host:port holding the address and port of the server to connect to. If JUJU_TEST_ELASTICSEARCH is not specified then localhost:9200 will be used.

func (*ElasticSearchSuite) LoadESConfig

func (s *ElasticSearchSuite) LoadESConfig(index string, settings, mapping interface{}) error

LoadESConfig loads a canned test configuration to the specified index

func (*ElasticSearchSuite) NewIndex

func (s *ElasticSearchSuite) NewIndex(c *gc.C) string

NewIndex creates a new index name and ensures that it will be cleaned up at end of the test.

func (*ElasticSearchSuite) SetUpSuite

func (s *ElasticSearchSuite) SetUpSuite(c *gc.C)

func (*ElasticSearchSuite) SetUpTest

func (s *ElasticSearchSuite) SetUpTest(c *gc.C)

func (*ElasticSearchSuite) TearDownSuite

func (s *ElasticSearchSuite) TearDownSuite(c *gc.C)

func (*ElasticSearchSuite) TearDownTest

func (s *ElasticSearchSuite) TearDownTest(c *gc.C)

type IsolatedMgoESSuite

func (*IsolatedMgoESSuite) SetUpSuite

func (s *IsolatedMgoESSuite) SetUpSuite(c *gc.C)

func (*IsolatedMgoESSuite) SetUpTest

func (s *IsolatedMgoESSuite) SetUpTest(c *gc.C)

func (*IsolatedMgoESSuite) TearDownSuite

func (s *IsolatedMgoESSuite) TearDownSuite(c *gc.C)

func (*IsolatedMgoESSuite) TearDownTest

func (s *IsolatedMgoESSuite) TearDownTest(c *gc.C)

type IsolatedMgoSuite

type IsolatedMgoSuite struct {
	jujutesting.IsolationSuite
	jujutesting.MgoSuite
}

func (*IsolatedMgoSuite) SetUpSuite

func (s *IsolatedMgoSuite) SetUpSuite(c *gc.C)

func (*IsolatedMgoSuite) SetUpTest

func (s *IsolatedMgoSuite) SetUpTest(c *gc.C)

func (*IsolatedMgoSuite) TearDownSuite

func (s *IsolatedMgoSuite) TearDownSuite(c *gc.C)

func (*IsolatedMgoSuite) TearDownTest

func (s *IsolatedMgoSuite) TearDownTest(c *gc.C)

Directories

Path Synopsis

Jump to